@@ -18,8 +18,8 @@
  */
 
 /**
- * <b>Tobago Framework Component Tag Library 4.5.x -
- * (C) Copyright 2005-2021 The Apache Software Foundation</b>
+ * <b>Tobago Framework Component Tag Library 4.6.0 -
+ * (C) Copyright 2005-2022 The Apache Software Foundation</b>
  */
 @org.apache.myfaces.tobago.apt.annotation.Taglib(
     shortName = "tc",
@@ -28,6 +28,6 @@
         "org.apache.myfaces.tobago.webapp.TobagoServletContextListener",
         "org.apache.myfaces.tobago.webapp.SecretSessionListener"},
     name = "tobago",
-    displayName = "Tobago Components 4.5.x")
+    displayName = "Tobago Components 4.6.0")
 
 package org.apache.myfaces.tobago.internal.taglib.component;
